package com.zyc.system.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zyc.system.mapper.AmsApplicationGridServicesMapper;
import com.zyc.system.domain.AmsApplicationGridServices;
import com.zyc.system.service.IAmsApplicationGridServicesService;

/**
 * AMS应用网格服务Service业务层处理
 * 
 * @author zyc
 * @date 2024-12-26
 */
@Service
public class AmsApplicationGridServicesServiceImpl implements IAmsApplicationGridServicesService 
{
    @Autowired
    private AmsApplicationGridServicesMapper amsApplicationGridServicesMapper;

    /**
     * 查询AMS应用网格服务
     * 
     * @param id AMS应用网格服务主键
     * @return AMS应用网格服务
     */
    @Override
    public AmsApplicationGridServices selectAmsApplicationGridServicesById(Integer id)
    {
        return amsApplicationGridServicesMapper.selectAmsApplicationGridServicesById(id);
    }

    /**
     * 查询AMS应用网格服务列表
     * 
     * @param amsApplicationGridServices AMS应用网格服务
     * @return AMS应用网格服务
     */
    @Override
    public List<AmsApplicationGridServices> selectAmsApplicationGridServicesList(AmsApplicationGridServices amsApplicationGridServices)
    {
        return amsApplicationGridServicesMapper.selectAmsApplicationGridServicesList(amsApplicationGridServices);
    }

    /**
     * 新增AMS应用网格服务
     * 
     * @param amsApplicationGridServices AMS应用网格服务
     * @return 结果
     */
    @Override
    public int insertAmsApplicationGridServices(AmsApplicationGridServices amsApplicationGridServices)
    {
        return amsApplicationGridServicesMapper.insertAmsApplicationGridServices(amsApplicationGridServices);
    }

    /**
     * 修改AMS应用网格服务
     * 
     * @param amsApplicationGridServices AMS应用网格服务
     * @return 结果
     */
    @Override
    public int updateAmsApplicationGridServices(AmsApplicationGridServices amsApplicationGridServices)
    {
        return amsApplicationGridServicesMapper.updateAmsApplicationGridServices(amsApplicationGridServices);
    }

    /**
     * 批量删除AMS应用网格服务
     * 
     * @param ids 需要删除的AMS应用网格服务主键
     * @return 结果
     */
    @Override
    public int deleteAmsApplicationGridServicesByIds(Integer[] ids)
    {
        return amsApplicationGridServicesMapper.deleteAmsApplicationGridServicesByIds(ids);
    }

    /**
     * 删除AMS应用网格服务信息
     * 
     * @param id AMS应用网格服务主键
     * @return 结果
     */
    @Override
    public int deleteAmsApplicationGridServicesById(Integer id)
    {
        return amsApplicationGridServicesMapper.deleteAmsApplicationGridServicesById(id);
    }
}
